<?php

namespace Drupal\renderkit\FieldDisplayProcessor;

/**
 * Decorator to add default field classes to the processed element.
 *
 * If the decorated component fully rewrites the field display render element,
 * this decorator can make it behave a little bit more like the original field
 * display.
 */
class FieldDisplayProcessor_FieldClasses implements FieldDisplayProcessorInterface {

  /**
   * @var \Drupal\renderkit\FieldDisplayProcessor\FieldDisplayProcessorInterface
   */
  private $decorated;

  /**
   * @param \Drupal\renderkit\FieldDisplayProcessor\FieldDisplayProcessorInterface $decorated
   */
  public function __construct(FieldDisplayProcessorInterface $decorated) {
    $this->decorated = $decorated;
  }

  /**
   * @param array $element
   *   Render array with ['#theme' => 'field', ..]
   *
   * @return array
   */
  public function process(array $element) {
    $build = $this->decorated->process($element);
    $build['#attributes']['class'][] = 'field';
    $build['#attributes']['class'][] = 'field-name-' . str_replace('_', '-', $element['#field_name']);
    $build['#attributes']['class'][] = 'field-type-' . str_replace('_', '-', $element['#field_type']);
    $build['#attributes']['class'][] = 'field-label-' . $element['#label_display'];
    return $build;
  }

}
